@@ -1,3 +1,6 @@
+"""
+.. include:: ../README.md
+"""
 import nowcastlib.rawdata
 from importlib_metadata import version
 
